<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * iPay enrolments plugin settings and presets.
 *
 * @package    enrol_ipay
 * @copyright  iPay Limited
 * @author     Moses King'ori <moseskariuki2119@gmail.com>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

if ($ADMIN->fulltree) {

	//--- settings ------------------------------------------------------------------------------------------
	$settings->add(new admin_setting_heading('enrol_ipay_settings', '', get_string('pluginname_desc', 'enrol_ipay')));

	$settings->add(new admin_setting_configtext('enrol_ipay/vendorid', get_string('vendorid', 'enrol_ipay'), get_string('vendorid_desc', 'enrol_ipay'), '', PARAM_TEXT));
	$settings->add(new admin_setting_configtext('enrol_ipay/hashkey', get_string('hashkey', 'enrol_ipay'), get_string('hashkey_desc', 'enrol_ipay'), '', PARAM_TEXT));
	$settings->add(new admin_setting_configtext('enrol_ipay/merchantname', get_string('merchantname', 'enrol_ipay'), get_string('merchantname_desc', 'enrol_ipay'), '', PARAM_TEXT));
	$ipaycountries = enrol_get_plugin('ipay')->get_countries();
	$settings->add(new admin_setting_configselect('enrol_ipay/country', get_string('country', 'enrol_ipay'), '', 'ke', $ipaycountries));

	$sandboxoptions = enrol_get_plugin('ipay')->get_yesno();
	$settings->add(new admin_setting_configselect('enrol_ipay/sandbox', get_string('sandbox', 'enrol_ipay'), '', '0', $sandboxoptions));

	$autopayoptions = enrol_get_plugin('ipay')->get_yesno();
	$settings->add(new admin_setting_configselect('enrol_ipay/autopay', get_string('autopay', 'enrol_ipay'), '', '0', $autopayoptions));

	$settings->add(new admin_setting_configcheckbox('enrol_ipay/mailstudents', get_string('mailstudents', 'enrol_ipay'), '', 0));

	$settings->add(new admin_setting_configcheckbox('enrol_ipay/mailteachers', get_string('mailteachers', 'enrol_ipay'), '', 0));

	$settings->add(new admin_setting_configcheckbox('enrol_ipay/mailadmins', get_string('mailadmins', 'enrol_ipay'), '', 0));

	// Note: let's reuse the ext sync constants and strings here, internally it is very similar,
	//       it describes what should happen when users are not supposed to be enrolled any more.
	$options = array(
		ENROL_EXT_REMOVED_KEEP => get_string('extremovedkeep', 'enrol'),
		ENROL_EXT_REMOVED_SUSPENDNOROLES => get_string('extremovedsuspendnoroles', 'enrol'),
		ENROL_EXT_REMOVED_UNENROL => get_string('extremovedunenrol', 'enrol'),
	);
	$settings->add(new admin_setting_configselect('enrol_ipay/expiredaction', get_string('expiredaction', 'enrol_ipay'), get_string('expiredaction_help', 'enrol_ipay'), ENROL_EXT_REMOVED_SUSPENDNOROLES, $options));

	//--- enrol instance defaults ----------------------------------------------------------------------------
	$settings->add(new admin_setting_heading('enrol_ipay_defaults',
		get_string('enrolinstancedefaults', 'admin'), get_string('enrolinstancedefaults_desc', 'admin')));

	$options = array(ENROL_INSTANCE_ENABLED => get_string('yes'),
		ENROL_INSTANCE_DISABLED => get_string('no'));
	$settings->add(new admin_setting_configselect('enrol_ipay/status',
		get_string('status', 'enrol_ipay'), get_string('status_desc', 'enrol_ipay'), ENROL_INSTANCE_DISABLED, $options));

	$settings->add(new admin_setting_configtext('enrol_ipay/cost', get_string('cost', 'enrol_ipay'), '', 0, PARAM_FLOAT, 4));

	$ipaycurrencies = enrol_get_plugin('ipay')->get_currencies();
	$settings->add(new admin_setting_configselect('enrol_ipay/currency', get_string('currency', 'enrol_ipay'), '', 'USD', $ipaycurrencies));

	if (!during_initial_install()) {
		$options = get_default_enrol_roles(context_system::instance());
		$student = get_archetype_roles('student');
		$student = reset($student);
		$settings->add(new admin_setting_configselect('enrol_ipay/roleid',
			get_string('defaultrole', 'enrol_ipay'), get_string('defaultrole_desc', 'enrol_ipay'), $student->id, $options));
	}

	$settings->add(new admin_setting_configduration('enrol_ipay/enrolperiod',
		get_string('enrolperiod', 'enrol_ipay'), get_string('enrolperiod_desc', 'enrol_ipay'), 0));
}
